@@ -8,17 +8,15 @@ from scipy.stats.distributions import chi2
 from scipy.special import expit, xlog1py, xlogy
 from progress.bar import Bar
 from .MakeTable import MakeTwoByTwoTable
-
-def logistic(q, s):
-    return expit(q+s)
+from .Marginal import calculateMarginals
 
 def itemPb(q, s, k, b, linear = False):
     if linear:
         return xlogy(1, q + s + (q + s - 1) * np.ceil(-k/b)) + xlog1py(np.floor(k), -1*(q+s))
-    return  xlogy(1, logistic(q,s) + (logistic(q,s) - 1) * np.ceil(-k/b)) + xlog1py(np.floor(k), -1*logistic(q,s))
+    return  xlogy(1, expit(q+s) + (expit(q+s) - 1) * np.ceil(-k/b)) + xlog1py(np.floor(k), -1*expit(q+s))
 
 def opFunction(x, data, linear = False):
-    return -1.0 * (np.array([ itemPb(x[item[1]], x[item[2]], item[0], item[3], linear) for item in data ]).sum())
+    return -1.0 * (np.array([ itemPb(x[item[2]], x[item[1]], item[0], item[3], linear) for item in data ]).sum())
 
 def opRestricted (x, data, linear = False):
     return -1.0 * (np.array([ itemPb(x[0], 0, item[0], item[3], linear) for item in data ]).sum())
@@ -35,21 +33,21 @@ def solve(dataset, summary = True, linear = False):
         bounds = None
     minValue = minimize(opFunction, [1/(2*(1+dataset['k'].mean()))]*len(smap), args=(data, linear), method='Powell', bounds=bounds)
     if minValue.success:
-        if linear:
-            fullResults = list(zip(smap, minValue.x.flatten().tolist()))
-            cols = ['Variable', 'Value']
-        else:
-            lmap = map(lambda x: logistic(x, 0), minValue.x.flatten().tolist())
-            fullResults = list(zip(smap, minValue.x.flatten().tolist(), lmap))
-            cols = ['Variable', 'Value', 'Logistic Transformed Value']
-        studentResults = fullResults[:uniqueStudents.size]
-        questionResults = fullResults[uniqueStudents.size:]
-        d = {
-            'student': pd.DataFrame(studentResults, columns=cols),
-            'rubric': pd.DataFrame(questionResults, columns=cols)
-        }
+        estX = minValue.x.flatten().tolist()
+        fullResults = list(zip(smap, estX))
+        cols = ['Variable', 'Value']
+        studentResults = pd.DataFrame(fullResults[:uniqueStudents.size], columns=cols)
+        questionResults = pd.DataFrame(fullResults[uniqueStudents.size:], columns=cols)
         if not summary:
-            return d
+            return {
+                'student': studentResults,
+                'rubric': questionResults
+            }
+        studentMarginals, rubricMarginals = calculateMarginals(data, estX, uniqueStudents.size, linear)
+        d = {
+            'student': studentResults.join(studentMarginals),
+            'rubric': questionResults.join(rubricMarginals)
+        }
         d['AIC'] = 2*(uniqueStudents.size+uniqueQuestion.size)+2*minValue.fun
         d['BIC'] = (uniqueStudents.size+uniqueQuestion.size)*math.log(len(studentCode))+2*minValue.fun
         d['n'] = len(studentCode)
@@ -175,10 +173,8 @@ def getResults(dataset: pd.DataFrame,c=0.025, rubric=False, n=1000, linear=False
                 'Confidence Interval': ci,
             }
             if not linear:
-                transformedci = (logistic(df.quantile(q=c),0), logistic(df.quantile(q=(1-c)),0))
-                vDict['Logistic Transformed Confidence Interval'] = transformedci
-            pvalue = (percentileofscore(df, 0) / 100)*2 if np.mean(df) > 0 else (1 - (percentileofscore(df, 0) / 100))*2
-            vDict['P-Value'] = pvalue
+                pvalue = (percentileofscore(df, 0) / 100)*2 if np.mean(df) > 0 else (1 - (percentileofscore(df, 0) / 100))*2
+                vDict['P-Value'] = pvalue
             l.append(vDict)
         McFadden = None
         LR = None
